@@ -178,9 +178,8 @@ zoomable_zoom_to_fit_cb (BonoboZoomable *zoomable, GgvControl *control)
 	g_return_if_fail (control != NULL);
 	g_return_if_fail (GGV_IS_CONTROL (control));
 
-	ggv_postscript_view_zoom_to_fit (control->priv->ps_view, TRUE);
-	new_zoom_level = ggv_postscript_view_get_zoom_factor
-			(control->priv->ps_view);
+	new_zoom_level =
+		ggv_postscript_view_zoom_to_fit (control->priv->ps_view, FALSE);
 
 	gtk_signal_emit_by_name (GTK_OBJECT (zoomable), "set_zoom_level",
 							 new_zoom_level);
