@@ -248,6 +248,9 @@ void button_press_callback(GtkWidget *widget, GdkEventButton *event,
                 if(ggv->toolbar_vis_pu)
                         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ggv->toolbar_vis_pu),
                                                        ggv->show_toolbar);
+                if(ggv->statusbar_vis_pu)
+                        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ggv->statusbar_vis_pu),
+                                                       ggv->show_statusbar);
                 if(ggv->panel_vis_pu)
                         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ggv->panel_vis_pu),
                                                        ggv->show_panel);
@@ -293,9 +296,6 @@ void button_release_callback(GtkWidget *widget, GdkEventButton *event,
                         gtk_gs_end_scroll(GTK_GS(ggv->gs));
                 }
                 break;
-        case 2:
-                ggv->cd->incrop = 0;
-                break;
         default:
                 break;
         }
@@ -474,6 +474,7 @@ void show_menubar_callback(GtkWidget *widget, gpointer data)
         ggv_menus_set_visible(ggv, GTK_CHECK_MENU_ITEM(widget)->active);
 }
 
+
 void show_toolbar_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *) data;
@@ -482,6 +483,14 @@ void show_toolbar_callback(GtkWidget *widget, gpointer data)
 }
 
 
+void show_statusbar_callback(GtkWidget *widget, gpointer data)
+{
+        ggv_window *ggv = (ggv_window *) data;
+        
+	ggv_statusbar_set_visible(ggv, GTK_CHECK_MENU_ITEM(widget)->active);
+}
+
+
 void show_panel_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *) data;
@@ -516,6 +525,18 @@ void interpreter_message_callback(GtkGS *gs, gchar *msg, gpointer data)
         add_gs_status_text (ggv, msg, TRUE);
 }
 
+void document_changed_callback(GtkGS *gs, gpointer data)
+{
+        gchar *fname;
+        ggv_window *ggv;
+
+        ggv = (ggv_window *)data;
+        fname = g_strdup(GTK_GS(ggv->gs)->gs_filename);
+        load_gs(ggv, fname);
+        g_free(fname);
+}
+
+
 void key_pressed_event_callback(GtkWidget *widget, GdkEventKey *event,
                                 gpointer data)
 {
@@ -681,12 +702,14 @@ void open_callback(GtkWidget *widget, gpointer data)
         gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(ggv->file_sel));
 
         /* Switch to the directory where the current file came from */
-        if ((GTK_GS (ggv->gs)->gs_filename != NULL) &&
-	    ((dirname = g_dirname(GTK_GS (ggv->gs)->gs_filename)) != NULL) &&
-            (strcmp(dirname, ".") != 0)) {
-                gtk_file_selection_complete(GTK_FILE_SELECTION(ggv->file_sel),
-                                            dirname);
-		g_free (dirname);
+        if(GTK_GS (ggv->gs)->gs_filename != NULL) {
+                if((dirname = g_dirname(GTK_GS (ggv->gs)->gs_filename)) != NULL) {
+                        if(strcmp(dirname, ".") != 0) {
+                                gtk_file_selection_complete(GTK_FILE_SELECTION(ggv->file_sel),
+                                                            dirname);
+                        }
+                        g_free(dirname);
+                }
 	}
         gtk_widget_show(ggv->file_sel);
 }
@@ -878,11 +901,14 @@ void save_callback(GtkWidget *widget, gpointer data) {
                 gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(ggv->save_file_sel));
                 
                 /* Switch to the directory where the current file came from */
-                if ((GTK_GS (ggv->gs)->gs_filename != NULL) &&
-		    ((dirname = g_dirname(GTK_GS (ggv->gs)->gs_filename)) != NULL)) {
-                        gtk_file_selection_complete(GTK_FILE_SELECTION(ggv->save_file_sel),
-                                                    dirname);
-			g_free (dirname);
+                if(GTK_GS (ggv->gs)->gs_filename != NULL) {
+                        if((dirname = g_dirname(GTK_GS (ggv->gs)->gs_filename)) != NULL) {
+                                if(strcmp(dirname, ".") != 0) {
+                                        gtk_file_selection_complete(GTK_FILE_SELECTION(ggv->save_file_sel),
+                                                                    dirname);
+                                }
+                                g_free (dirname);
+                        }
 		}
                 gtk_widget_show(ggv->save_file_sel);
         }
@@ -1117,6 +1143,7 @@ void prefs_apply_callback(GtkWidget *w, gint page, ggv_prefs *p)
 	ggv_toolbar = GTK_TOGGLE_BUTTON(p->toolbar)->active;
         ggv_toolbar_labels = GTK_TOGGLE_BUTTON(p->tblabels)->active;
         ggv_menubar = GTK_TOGGLE_BUTTON(p->mbar)->active;
+        ggv_statusbar = GTK_TOGGLE_BUTTON(p->sbar)->active;
         ggv_auto_jump = GTK_TOGGLE_BUTTON(p->auto_jump)->active;
 
         gtk_gs_defaults_save();
