@@ -89,6 +89,7 @@ void synchronize_orientation_items_wd(ggv_window *ggv);
 /* set visibility of components */
 void ggv_menus_set_visible(ggv_window *ggv, gboolean v);
 void ggv_toolbar_set_visible(ggv_window *ggv, gboolean v);
+void ggv_statusbar_set_visible(ggv_window *ggv, gboolean v);
 void ggv_toolbar_set_labels(ggv_window *ggv, gboolean labels);
 void ggv_panel_set_visible(ggv_window *ggv, gboolean v);
 
@@ -118,7 +119,7 @@ struct _ggv_window {
         GtkWidget *appbar;
         GtkObject *hadj, *vadj;
         GtkWidget *gs;
-        gboolean show_menus, show_panel, show_toolbar;
+        gboolean show_menus, show_panel, show_toolbar, show_statusbar;
         gboolean loaded;
         gboolean pan;
         gboolean pane_auto_jump;	/* ...to top of new page */
@@ -142,7 +143,8 @@ struct _ggv_window {
         GtkWidget *recenteritem, *recenterpu;
         GtkWidget *zoominbutton, *zoominpu;                    /* zoom buttons */
         GtkWidget *zoomoutbutton, *zoomoutpu;
-        GtkWidget *panel_vis, *menus_vis, *toolbar_vis;  /* menu/side panel/toolbar visibility check items in menus */
+        GtkWidget *panel_vis, *menus_vis;
+        GtkWidget *statusbar_vis, *toolbar_vis;  /* menu/side panel/toolbar visibility check items in menus */
         GtkWidget *watchdoc_menu;
         GtkWidget *antialiased_menu;
         GtkWidget *override_size_menu;
@@ -152,7 +154,8 @@ struct _ggv_window {
         GtkWidget **paper_menu;
         GtkWidget *orientation_menu[MENU_ORIENTATION_SIZE];
 
-        GtkWidget *panel_vis_pu, *menus_vis_pu, *toolbar_vis_pu; /* and in popup menu */
+        GtkWidget *panel_vis_pu, *menus_vis_pu;
+        GtkWidget *toolbar_vis_pu, *statusbar_vis_pu; /* and in popup menu */
  	GtkWidget *toggleakt, *toggleall,          		 /* (un)mark pages */
                   *toggleeven, *toggleodd, *clearall,
                   *toggleakt_pu, *toggleall_pu,
@@ -171,7 +174,7 @@ struct _ggv_prefs
         GtkWidget *size, *zoom, *orientation, *units;         /* option menus */
         GtkWidget *watch, *aa, *override_size, *respect_eof, *show_scroll_rect; /* checkbuttons */
         GtkWidget *override_orientation;
-        GtkWidget *sidebar, *mbar, *toolbar, *tblabels, *savegeo,*auto_jump;/* checkbuttons */
+        GtkWidget *sidebar, *mbar, *sbar, *toolbar, *tblabels, *savegeo,*auto_jump;/* checkbuttons */
         GtkWidget **size_choice;                              /* paper items */
         GtkWidget *zoom_choice[MENU_ZOOM_SIZE];               /* zoom items */
         GtkWidget *orientation_choice[MENU_ORIENTATION_SIZE]; /* orientation items */
