@@ -20,8 +20,8 @@ static GConfClient *gconf_client;
 typedef struct _GtkGSDefaults 
 {
         gboolean   antialiased;
-        gboolean   override_media;
-        gint       default_media;
+        gboolean   override_size;
+        gint       default_size;
 	gboolean   watch_doc;
         gboolean   override_orientation;
         gboolean   respect_eof;
@@ -39,15 +39,15 @@ static GtkGSDefaults gtk_gs_defaults = {
 };
 
 void
-gtk_gs_defaults_set_media(gint iNewPageMedia)
+gtk_gs_defaults_set_size(gint iNewPageSize)
 {
-        gtk_gs_defaults.default_media = iNewPageMedia;
+        gtk_gs_defaults.default_size = iNewPageSize;
 }
 
 gint
-gtk_gs_defaults_get_media()
+gtk_gs_defaults_get_size()
 {
-        return gtk_gs_defaults.default_media;
+        return gtk_gs_defaults.default_size;
 }
 
 void
@@ -63,15 +63,15 @@ gtk_gs_defaults_get_watch_doc()
 }
 
 void
-gtk_gs_defaults_set_override_media(gboolean bOverMedia)
+gtk_gs_defaults_set_override_size(gboolean bOverrSize)
 {
-        gtk_gs_defaults.override_media = bOverMedia;
+        gtk_gs_defaults.override_size = bOverrSize;
 }
 
 gboolean
-gtk_gs_defaults_get_override_media()
+gtk_gs_defaults_get_override_size()
 {
-        return gtk_gs_defaults.override_media;
+        return gtk_gs_defaults.override_size;
 }
 
 void
@@ -249,8 +249,8 @@ gtk_gs_defaults_load()
         gtk_gs_defaults_set_watch_doc
                 (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/watch_doc",
                                        NULL));
-        gtk_gs_defaults_set_override_media
-                (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/override_media",
+        gtk_gs_defaults_set_override_size
+                (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/override_size",
                                        NULL));
         gtk_gs_defaults_set_override_orientation
                 (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/override_orientation",
@@ -258,8 +258,8 @@ gtk_gs_defaults_load()
         gtk_gs_defaults_set_antialiased
                 (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/antialiasing",
                                        NULL));
-        gtk_gs_defaults_set_media
-                (gconf_client_get_int(gconf_client, "/apps/ggv/gtkgs/media",
+        gtk_gs_defaults_set_size
+                (gconf_client_get_int(gconf_client, "/apps/ggv/gtkgs/size",
                                       NULL));
         gtk_gs_defaults_set_zoom_factor
                 (gconf_client_get_float(gconf_client, "/apps/ggv/gtkgs/zoom",
@@ -293,14 +293,14 @@ gtk_gs_defaults_save()
                               gtk_gs_defaults_get_respect_eof(), NULL);
         gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/watch_doc",
                               gtk_gs_defaults_get_watch_doc(), NULL);
-        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/override_media",
-                              gtk_gs_defaults_get_override_media(), NULL);
+        gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/override_size",
+                              gtk_gs_defaults_get_override_size(), NULL);
         gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/override_orientation",
                               gtk_gs_defaults_get_override_orientation(), NULL);
         gconf_client_set_bool(gconf_client, "/apps/ggv/gtkgs/antialiasing",
                               gtk_gs_defaults_get_antialiased(), NULL);
-        gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/media",
-                             gtk_gs_defaults_get_media(), NULL);
+        gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/size",
+                             gtk_gs_defaults_get_size(), NULL);
         gconf_client_set_int(gconf_client, "/apps/ggv/gtkgs/orientation",
                              gtk_gs_defaults_get_orientation(), NULL);
         gconf_client_set_float(gconf_client, "/apps/ggv/gtkgs/zoom",
@@ -337,17 +337,17 @@ gtk_gs_defaults_changed(GConfClient* client, guint cnxn_id,
                 gtk_gs_defaults_set_zoom_factor
                         (gconf_client_get_float(gconf_client, "/apps/ggv/gtkgs/zoom",
                                                 NULL));
-        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/media"))
-                gtk_gs_defaults_set_media
-                        (gconf_client_get_int(gconf_client, "/apps/ggv/gtkgs/media",
+        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/size"))
+                gtk_gs_defaults_set_size
+                        (gconf_client_get_int(gconf_client, "/apps/ggv/gtkgs/size",
                                               NULL));
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/antialiasing"))
                 gtk_gs_defaults_set_antialiased
                         (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/antialiasing",
                                                NULL));
-        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_media"))
-                gtk_gs_defaults_set_override_media
-                        (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/override_media",
+        else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_size"))
+                gtk_gs_defaults_set_override_size
+                        (gconf_client_get_bool(gconf_client, "/apps/ggv/gtkgs/override_size",
                                                NULL));
         else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc"))
                 gtk_gs_defaults_set_watch_doc
