@@ -141,7 +141,7 @@ The DONE message indicates that ghostscript has finished processing.
 typedef void (*InterpreterMessageSignal)(GtkObject *object, gchar *msg,
                                          gpointer data);
 
-enum { INTERPRETER_MESSAGE, LAST_SIGNAL };
+enum { INTERPRETER_MESSAGE, DOCUMENT_CHANGED, LAST_SIGNAL };
 
 static gboolean broken_pipe = FALSE;
 
@@ -199,8 +199,6 @@ gtk_gs_marshaller(GtkObject *object, GtkSignalFunc func,
 static void
 gtk_gs_init (GtkGS *gs)
 {
-        gint i;
-
         gs->bpixmap     = NULL;
         gs->use_bpixmap = TRUE;
 
@@ -262,10 +260,8 @@ gtk_gs_init (GtkGS *gs)
         gs->respect_eof = gtk_gs_defaults_get_respect_eof();
         gs->watch_doc = gtk_gs_defaults_get_watch_doc();
         gs->show_scroll_rect = gtk_gs_defaults_get_show_scroll_rect();
-
-        i = 0;
-        gs->gconf_notify_id = g_new0(guint, 6);
-        gs->gconf_notify_id[i++] = gconf_client_notify_add
+        
+        gs->gconf_notify_id = gconf_client_notify_add
                 (gtk_gs_defaults_gconf_client(), "/apps/ggv/gtkgs",
                  (GConfClientNotifyFunc)gtk_gs_defaults_changed,
                  gs, NULL, NULL);
@@ -286,6 +282,10 @@ gtk_gs_class_init (GtkGSClass *klass)
                        "interpreter_message", GTK_RUN_LAST, object_class->type,
                        GTK_SIGNAL_OFFSET(GtkGSClass, interpreter_message),
                        gtk_gs_marshaller, GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+	gtk_gs_signals[DOCUMENT_CHANGED] = gtk_signal_new(
+                       "document_changed", GTK_RUN_LAST, object_class->type,
+                       GTK_SIGNAL_OFFSET(GtkGSClass, document_changed),
+                       gtk_signal_default_marshaller, GTK_TYPE_NONE, 0);
         gtk_object_class_add_signals(object_class, gtk_gs_signals, LAST_SIGNAL);
 
         object_class->destroy = gtk_gs_destroy;
@@ -401,7 +401,6 @@ static void
 gtk_gs_destroy (GtkObject *object)
 {
         GtkGS *gs;
-        gint i;
 
         g_return_if_fail (object != NULL);
         g_return_if_fail (GTK_IS_GS (object));
@@ -410,13 +409,15 @@ gtk_gs_destroy (GtkObject *object)
 
         gtk_gs_cleanup(gs);
 
-	if(gs->input_buffer)
+	if(gs->input_buffer) {
 		g_free(gs->input_buffer);
+                gs->input_buffer = NULL;
+        }
 
-        for(i = 0; gs->gconf_notify_id[i] != 0; i++) {
+        if(gs->gconf_notify_id != -1) {
                 gconf_client_notify_remove(gtk_gs_defaults_gconf_client(),
-                                           gs->gconf_notify_id[i]);
-                gs->gconf_notify_id[i] = 0;
+                                           gs->gconf_notify_id);
+                gs->gconf_notify_id = -1;
         }
 
         if (GTK_OBJECT_CLASS (parent_class)->destroy)
@@ -743,7 +744,7 @@ timer_callback (gpointer data)
 
         g_assert (data);
 
-        gs = GTK_GS (data);
+        gs = GTK_GS(data);
 
         /* remove timer if no valid file is loaded */
 	if (!gs->loaded || !gs->watch_doc || !gs->gs_psfile) {
@@ -753,8 +754,9 @@ timer_callback (gpointer data)
 
 	if (!gs->busy && !stat(gs->gs_filename, &sbuf) &&
 	    (sbuf.st_mtime != gs->mtime) &&
-	    (time (NULL) - sbuf.st_mtime >= GTK_GS_WATCH_TIMEOUT))
-		gtk_gs_set_page_size(gs, -1, gs->current_page);
+	    (time (NULL) - sbuf.st_mtime >= GTK_GS_WATCH_TIMEOUT)) {
+                gtk_signal_emit(GTK_OBJECT(gs), gtk_gs_signals[DOCUMENT_CHANGED]);
+        }
 
         return TRUE;
 }
@@ -1018,13 +1020,6 @@ start_interpreter (GtkGS *gs)
 	if (gs->disable_start == TRUE)
                 return 0;
 
-	/* change to directory where the input file is. This helps
-	 * with postscript-files which include other files using
-         * a relative path */
-	dir = g_dirname(gs->gs_filename);
-	chdir(dir);
-	g_free(dir);
-
         /* set up the args... */
         gs_args = g_strsplit(gtk_gs_defaults_get_interpreter_cmd(),
                              " ", NUM_GS_ARGS);
@@ -1064,7 +1059,7 @@ start_interpreter (GtkGS *gs)
 	if (pipe (std_err) == -1) {
 		close_pipe(std_in);
 		close_pipe(std_out);
-		return -1;
+                return -1;
 	}
 
         gs->busy = TRUE;
@@ -1104,6 +1099,13 @@ start_interpreter (GtkGS *gs)
                 gv_env = g_strdup_printf ("GHOSTVIEW=%ld",
                                           ((GdkWindowPrivate*)(gs->pstarget))->xwindow);
                 putenv (gv_env);
+                /* change to directory where the input file is. This helps
+                 * with postscript-files which include other files using
+                 * a relative path */
+                dir = g_dirname(gs->gs_filename);
+                chdir(dir);
+                g_free(dir);
+
                 execvp(argv[0], argv);
                 
                 /* Notify error */
@@ -1735,9 +1737,7 @@ gtk_gs_goto_page (GtkGS *gs, gint page)
                 /* has it changed? */
                 if (!stat(gs->gs_filename, &sbuf) &&
                     gs->mtime != sbuf.st_mtime) {
-                        gchar *fname = g_strdup(gs->gs_filename);
-                        gtk_gs_load (gs, fname);
-                        g_free(fname);
+                        gtk_signal_emit(GTK_OBJECT(gs), gtk_gs_signals[DOCUMENT_CHANGED]);
                 }
         }
 
