@@ -111,7 +111,7 @@ struct _GtkGS
         gint        real_orientation;      /* Real orientation from the document */
         gint       *pages_marked;
 
-        guint      *gconf_notify_id;
+        guint      gconf_notify_id;
 };
 
 struct _GtkGSClass
@@ -127,6 +127,7 @@ struct _GtkGSClass
         GConfClient *gconf_client;
 
         void (*interpreter_message)(GtkGS *, gchar *, gpointer);
+        void (*document_changed)(GtkGS *, gpointer);
 };
 
 
